/*
 * kylin-burner--Qt
 *
 * Copyright (C) 2020, Tianjin KYLIN Information Technology Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yan Huanzhang <yanhuanzhang@kylinos.cn>
 *          Wang Chenglong <wangchenglong@kylinos.cn>
 */

#ifndef DATADIRECTORY_H
#define DATADIRECTORY_H

#include "datafile.h"

class DataDirectory : public DataFile
{
    Q_OBJECT
public:
    explicit DataDirectory(QString path, QObject *parent = nullptr, bool fromDisk = false);
    ~DataDirectory();
public:
    DataFile *at(int);
    int of(DataFile *);
    int of(DataDirectory *);
    bool take(DataFile *);
    void append(DataFile *d);
    void filterAppend(DataFile *d) { m_oChildren << d; }
    int count() const;
    int counts() const { return m_oChildren.size(); }
    unsigned long total() const { return m_u64Dirs + m_u64Files; }
    unsigned long nSize() const { return m_u64NewDataSize; }
    bool isRoot() const { return m_bIsRoot; }
    bool canClean() const;
    bool duplicate(QString) const;
    void rename(QString, bool add = false);
    void updateChild(QString, QString);
    void clear();
    void clean();
    void copy();
    void *findChildByDisplay(QString, bool child = false);
    bool filterHidden() const { return m_bFilterHidden; }
    bool filterBrokenSymbolLinks() const { return m_bFilterBroken; }
    bool repleaceSymbolLinks() const { return m_bRepleace; }
    void execHidden(bool b = true);
    void execBroken(bool b = true);
    void execRepleace(bool b = true);
    void turnViewFilterFileToHidden();
    void turnViewFilterFileToBrokenSymbolLinks();
    void turnViewFilterFileToRepleaceSymbolLinks();
    int  CountOneLevelNotDiskFile();
public slots:
    void doSize(unsigned long, bool);
    void doDirectory(bool, DataFile *);
    void doFile(bool, DataFile *);
    void doChild(DataFile *, bool);
private:
    bool                        m_bIsRoot;//是否为根节点
    bool                        m_bFilterHidden;//是否执行隐藏文件过滤
    bool                        m_bFilterBroken;//是否执行损坏连接文件过滤
    bool                        m_bRepleace;//是否执行连接文件替换
    unsigned long               m_u64Dirs;//当前文件夹下包含文件夹数量
    unsigned long               m_u64Files;//当前文件夹下包含文件数量
    unsigned long               m_u64NewDataSize;//当前文件夹下新添加文件大小
    QList<DataFile *>           m_oChildren;//当前文件夹下子文件
    QHash<QString, DataFile *>  m_oHashChildren;//当前文件夹下唯一子文件
signals:
    void updateSize(unsigned long);
};

#endif // DATADIRECTORY_H
