/*
 * kylin-burner--Qt
 *
 * Copyright (C) 2020, Tianjin KYLIN Information Technology Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yan Huanzhang <yanhuanzhang@kylinos.cn>
 *          Wang Chenglong <wangchenglong@kylinos.cn>
 */

#include "datasetting.h"
#include "src/po/translation.h"

#include <pwd.h>
#include <unistd.h>

#include <QDate>
#include <QDebug>
#include <QDir>

DataSetting::DataSetting(QObject *parent) :
    QObject(parent),
    m_iSpeed(0),
    m_SBurnFormat(QString("ISO9660")),
    m_bClean(false),
    m_bCloseSession(false),
    m_bCreateISO(false),
    m_bOpen(false)
{
    struct passwd *pwd;
    QDir dir;

    pwd = ::getpwuid(::getuid());

    m_oPreparer = _("KylinSoft");
    m_oPublisher = QString::fromUtf8(pwd->pw_name);
    m_oVolumnID = _("KylinBurner");
    m_oCopyright = _("Kylinsoft © %1 All rights.").arg(QDate::currentDate().toString("yyyy"));
    dir.setPath(QDir::homePath() + "/.cache/KylinBurner/");
    if (!dir.exists())
        dir.mkpath(dir.absolutePath());
    m_oTemporaryPth = dir.absolutePath();
    //qDebug()<<"new DataSetting(m_SBurnFormat==["<<m_SBurnFormat<<"])";
}

void DataSetting::load()
{
    //qDebug()<<"DataSetting::load() speed("<<m_iSpeed<<")";
    //qDebug()<<"DataSetting::load() burnFormat("<<m_SBurnFormat<<")";
    speed(m_iSpeed);
    clean(m_bClean);
    createISO(m_bCreateISO);
    closeSession(m_bCloseSession);
    open(m_bOpen);
    preparer(m_oPreparer);
    publisher(m_oPublisher);
    volumnID(m_oVolumnID);
    copyright(m_oCopyright);
    tempPath(m_oTemporaryPth);
    burnFormat(m_SBurnFormat);
}

DataSetting::~DataSetting()
{}
