/*
 * kylin-burner--Qt
 *
 * Copyright (C) 2020, Tianjin KYLIN Information Technology Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yan Huanzhang <yanhuanzhang@kylinos.cn>
 *          Wang Chenglong <wangchenglong@kylinos.cn>
 */

#include "src/view/mainwindow.h"
#include "src/frame/configuration.h"
#include "src/frame/logger.h"
#include "src/model/logicmain.h"
#include "src/model/monitorcdrom.h"
#include "src/model/menufactory.h"
#include "src/model/logiccopyimage.h"
#include "src/view/modaldialog.h"
#include "src/view/execdialog.h"
#include "src/view/filefilterrules.h"
#include "src/view/viewfilterfiles.h"
#include "src/view/kybaboutdialog.h"
#include "src/view/tip_loadmedium.h"
#include "src/po/translation.h"

#include <QApplication>
#include <QCommandLineParser>
#include <ukui-log4qt.h>
#include <QTranslator>

int main(int argc, char *argv[])
{
    QCommandLineParser *parser;

    QTranslator trans;
    // locale
    _KYBi18nLoad("kylin-burner", "/usr/share/locale/");
    _KYBi18nDomain("kylin-burner");

    // 4K
    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);

    QApplication a(argc, argv);

    //修复中文乱码问题
    const QString locale = QLocale::system().name();
    (void) setlocale(LC_ALL, QString(locale + ".UTF-8").toStdString().c_str());

    trans.load("qt_zh_CN.qm", "/usr/share/qt5/translations/");
    a.installTranslator(&trans);
    //initUkuiLog4qt("burner");

    ABOUT->init();
    CFG->init();
    //EverTime Burner Start, init [DataSetting]--Duplicate Data/Add Data/Delete Data/clean Data
    //it can reduce some error when user some operation
    CFG->set("DataSetting", "Duplicate Data", 0);
    CFG->set("DataSetting", "Add Data", false);
    CFG->set("DataSetting", "Delete Data", true);
    CFG->set("DataSetting", "Clean Data", true);

    LOGGER->init();
    MENU->init();
    MODAL->init();
    FILTERRULES->init();
    VIEWFILTERFILE->init();
    LoadMedium->init();
    MAIN->init();
    COPY_IMGAE->init();
    EXEC->init();

    parser = new QCommandLineParser;
    parser->addPositionalArgument( "urls", _("file(s) to open"), "[urls...]" );
    parser->addOption(QCommandLineOption("d", _("Running as debug model.")));
    parser->process(a);
    if (parser->isSet("d"))
        CFG->set("logger","level", 4);
    else
        CFG->set("logger","level", 1);

    //图标库主题的刻录图片名换为burner
    //a.setWindowIcon(QIcon::fromTheme("disk-burner"));
    a.setWindowIcon(QIcon::fromTheme("burner"));
    MainWindow w(parser->positionalArguments(), nullptr);
    w.show();
    MAIN->initISO();
    MONITOR->start();

    return a.exec();
}
