/*
 * kylin-burner--Qt
 *
 * Copyright (C) 2020, Tianjin KYLIN Information Technology Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yan Huanzhang <yanhuanzhang@kylinos.cn>
 *          Wang Chenglong <wangchenglong@kylinos.cn>
 */

#ifndef FILEFILTERMODEL_H
#define FILEFILTERMODEL_H

#include <QAbstractItemModel>

class FileFilterModel : public QAbstractItemModel
{
    Q_OBJECT
signals:
    void node(QIcon, QString);
    void root(QModelIndex);
    void recovery(QList<void *> hiddens, QList<void *> brokens, QList<void *> replaces);
public:
    explicit FileFilterModel(QObject *parent = nullptr);

    // Header:
    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
    bool setHeaderData(int section, Qt::Orientation orientation, const QVariant &value, int role = Qt::EditRole) override;

    // Basic functionality:
    QModelIndex index(int row, int column,
                      const QModelIndex &parent = QModelIndex()) const override;
    QModelIndex parent(const QModelIndex &index) const override;

    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
    int columnCount(const QModelIndex &parent = QModelIndex()) const override;

    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;

public:
    int filtered();
    void addFilterNode(void *);
    void addFilterData(int, void *);
    void updateIndex(int idx) { m_iIndex = idx; root(createIndex(idx, 0, m_oRoots.at(idx))); }
    void recovery(/*QModelIndexList idxes = QModelIndexList()*/);
    QList<void *> recoveryHiddenData(int, int);
    QList<void *> recoveryBrokenData(int, int);
    QList<void *> recoveryRepleaceData(int, int);
public slots:
    void deleteFilterNode(int);
    void showRules();
private:
    int            m_iIndex;
    QList<void *>  m_oRoots;
    QStringList    m_oHeaders;
};

#endif // FILEFILTERMODEL_H
