/*
 * kylin-burner--Qt
 *
 * Copyright (C) 2020, Tianjin KYLIN Information Technology Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yan Huanzhang <yanhuanzhang@kylinos.cn>
 *          Wang Chenglong <wangchenglong@kylinos.cn>
 */

#ifndef LOGICBURNIMAGE_H
#define LOGICBURNIMAGE_H

#include <QObject>
#include <QMutex>

class LogicBurnImage : public QObject
{
    Q_OBJECT
public:
    static LogicBurnImage *instance();
public:
    LogicBurnImage(const LogicBurnImage*)=delete;
    LogicBurnImage *operator =(const LogicBurnImage*)=delete;
public:
    void init();
    void destroy() { delete this; }
public:
    QIcon mediumIcon(int);
    QString display(int);
    QString tooltip(int);
public slots:
    void onNewISOPath(QString);
    void onNewBurner(int);
private:
    explicit LogicBurnImage(QObject *parent = nullptr);
    ~LogicBurnImage();
private:
    bool check();
private slots:
    void slotsNewBurner(void *);
    void slotsDeleteBurner(void *);
    void slotsBurnImage();
    void slotsSetting();
private:
    static LogicBurnImage *m_oInstance;
    static QMutex          m_oMutex;
private:
    QString                m_oISOPath;
    int                    m_iBurner;
    QStringList            m_oISOPaths;
    QList<void *>          m_oBurners;
signals:
    // log
    void info(QString); void warn(QString);
    void error(QString); void debug(QString);
    // logic
    void newISOPath(QString);
    void newBurner(QString, QString);
    void deleteBurner(int);
    void enableBurner(bool);
    void enableBusness(bool);
    void isoError(QString);
    void burnerError(QString);
    void ready(QString);
    void setting(void *);
};
#define BURNIMAGE LogicBurnImage::instance()
#endif // LOGICBURNIMAGE_H
