/*
 * kylin-burner--Qt
 *
 * Copyright (C) 2020, Tianjin KYLIN Information Technology Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yan Huanzhang <yanhuanzhang@kylinos.cn>
 *          Wang Chenglong <wangchenglong@kylinos.cn>
 */

#ifndef LOGICCOPYIMAGE_H
#define LOGICCOPYIMAGE_H

#include <QObject>
#include <QMutex>

class LogicCopyImage : public QObject
{
    Q_OBJECT
public:
    static LogicCopyImage *instance();
public:
    LogicCopyImage(const LogicCopyImage*)=delete;
    LogicCopyImage *operator =(const LogicCopyImage*)=delete;
public:
    void init(){}
    void destroy() { delete this; }
public:
    bool capacity();
    void updateISOPath(QString);
private:
    explicit LogicCopyImage(QObject *parent = nullptr);
    ~LogicCopyImage();
private slots:
    void slotsDestination(void *);
    void slotsDestinationChange(int i) { m_iDestination = i; }
    void slotsSource(void *);
    void slotsSourceChange(int i) { m_iSource = i; }
    void slotsNoMedium(void *);
    void slotsSetting();
    void slotsCopyImage();
    void slotsCopyData();
private:
    static LogicCopyImage *m_oInstance;
    static QMutex          m_oMutex;
private:
    int                    m_iSource;
    int                    m_iDestination;
    QList<void *>          m_oSources;
    QList<void *>          m_oDestinations;
signals:
    void destination(void *);
    void destination(int);
    void source(void *);
    void source(int);
    void setting(void *);
};
#define COPY_IMGAE LogicCopyImage::instance()
#endif // LOGICCOPYIMAGE_H
