/*
 * kylin-burner--Qt
 *
 * Copyright (C) 2020, Tianjin KYLIN Information Technology Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yan Huanzhang <yanhuanzhang@kylinos.cn>
 *          Wang Chenglong <wangchenglong@kylinos.cn>
 */

#ifndef MONITORCDROM_H
#define MONITORCDROM_H

#include <QObject>
#include <QThread>
#include <QMutex>

class MonitorCDROM : public QThread
{
    Q_OBJECT
signals:
    // cdrom
    void addCDROM(QString);
    void changeCDROM(QString);
    void removeCDROM(QString);
    // log
    void info(QString); void warn(QString);
    void error(QString); void debug(QString);
public:
    static MonitorCDROM *instance();
public:
    MonitorCDROM(const MonitorCDROM*)=delete;
    MonitorCDROM *operator =(const MonitorCDROM*)=delete;
public:
    void stop();
protected:
    void run() Q_DECL_OVERRIDE;
private:
    MonitorCDROM(QObject *parent = nullptr);
    ~MonitorCDROM();
private:
    int preception();
    void update();
    bool isCDROM(QString);
private:
    static MonitorCDROM *m_oInstance;
    static QMutex        m_oMutex;
private:
    bool                 m_bAppRunning;
    int                  m_iPreception;
    QStringList          m_oBlocks;
};
#define MONITOR MonitorCDROM::instance()
#endif // MONITORCDROM_H
