/*
 * kylin-burner--Qt
 *
 * Copyright (C) 2020, Tianjin KYLIN Information Technology Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yan Huanzhang <yanhuanzhang@kylinos.cn>
 *          Wang Chenglong <wangchenglong@kylinos.cn>
 */

#include "processmediainfo.h"
#include "src/view/modaldialog.h"
#include "src/data/datacdrom.h"

#include <QFileInfo>

ProcessMediaInfo::ProcessMediaInfo(void *d, QObject *parent) :
    ProcessBasic(parent),
    m_oCDROM(d),
    m_u64Size(0)
{}

bool ProcessMediaInfo::prepare()
{
    DataCDROM *cdrom;

    if (!MODAL->isHidden()) MODAL->close();
    disconnect(this, SIGNAL(success(QString)), TIP, SIGNAL(success(QString)));
    disconnect(this, SIGNAL(fail(QString)), TIP, SIGNAL(fail(QString)));

    m_oProcess->setProgram("dvd+rw-mediainfo");
    cdrom = static_cast<DataCDROM *>(m_oCDROM);
    m_oArguments << cdrom->device();
    m_oProcess->setArguments(m_oArguments);
    return true;
}

void ProcessMediaInfo::slotsError()
{
    QString error;

    error = m_oProcess->readAllStandardError();
}

void ProcessMediaInfo::slotsOutput()
{
    int     i;
    unsigned long t;
    unsigned long u;
    DataCDROM *cdrom;
    QString output;
    QStringList ss;
    QStringList sss;

    if (m_u64Size) return;

    output = m_oProcess->readAllStandardOutput();
    ss = output.split("\n");
    for (i = ss.size() - 1; i > 0; --i)
    {
        if (ss.at(i).startsWith("READ FORMAT CAPACITIES:")) break;
    }
    cdrom = static_cast<DataCDROM *>(m_oCDROM);
    if (cdrom->mediumType().contains("DVD+RW"))
    {
        ss = ss.takeAt(i + 1).split("=");
        //ss = ss.last().split("=");
        m_u64Size = ss.last().toULong();
    }
    if (cdrom->mediumType().contains("DVD-RW"))
    {
        //解决bug:70940和83628擦除后总容量显示错误
#if 0
        sss = ss.takeAt(i + 1).split("=");
        t = 0;
        u = 0;
        u = sss.last().toULong();//unformatted的容量
        sss = ss.takeAt(i + 2).split("=");
        t = sss.last().toULong();//00h(800h)的容量
        if (t > u) m_u64Size = t - u;
        else m_u64Size = u;
        //出现下面这种情况导致bug出现
        //no media:		4101552*2048=8399978496
        //00h(800):		2297888*2048=4706074624
#else
        sss = ss.takeAt(i + 2).split("=");
        t = sss.last().toULong();
        m_u64Size = t;
#endif
    }
}

ProcessMediaInfo::~ProcessMediaInfo()
{
#if 0
    if(m_oProcess!=nullptr)
    {
        delete m_oProcess;
        m_oProcess = nullptr;
    }
#else
    m_oProcess->close();
#endif
}
