/*
 * kylin-burner--Qt
 *
 * Copyright (C) 2020, Tianjin KYLIN Information Technology Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yan Huanzhang <yanhuanzhang@kylinos.cn>
 *          Wang Chenglong <wangchenglong@kylinos.cn>
 */

#include "processopenfile.h"

ProcessOpenFile::ProcessOpenFile(QString path, QObject *parent) :
    ProcessBasic(parent)
{
    m_oArguments << path;
    m_oPeony = new QProcess(this);
    m_oPeony->setProgram("peony");
    m_oPeonyArgs.clear();
    m_oPeonyArgs << "-i";
}

void ProcessOpenFile::setFile(QString path)
{
    m_oArguments.clear();
    m_oArguments << path;
    m_oPeonyArgs << path;
}

void ProcessOpenFile::exec()
{
    prepare();
    m_oProcess->setArguments(m_oArguments);
    m_oProcess->start();
    connect(m_oProcess, SIGNAL(started()), this, SLOT(slotsStart()));
    connect(m_oProcess, SIGNAL(readyReadStandardOutput()), this, SLOT(slotsOutput()));
    connect(m_oProcess, SIGNAL(readyReadStandardError()), this, SLOT(slotsError()));
    connect(m_oProcess, SIGNAL(finished(int,QProcess::ExitStatus)), this, SLOT(slotsFinished(int,QProcess::ExitStatus)));
}

bool ProcessOpenFile::prepare()
{
    m_oProcess->setProgram("xdg-open");
    return true;
}

void ProcessOpenFile::slotsError()
{
    m_oPeony->setArguments(m_oPeonyArgs);
    m_oPeony->start();
}

void ProcessOpenFile::slotsFinished(int errCode, QProcess::ExitStatus status)
{
}

ProcessOpenFile::~ProcessOpenFile()
{}
