/*
 * kylin-burner--Qt
 *
 * Copyright (C) 2020, Tianjin KYLIN Information Technology Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yan Huanzhang <yanhuanzhang@kylinos.cn>
 *          Wang Chenglong <wangchenglong@kylinos.cn>
 */

#ifndef BURNIMAGE_H
#define BURNIMAGE_H

#include <QWidget>
#include <QMutex>
#include <QLabel>
#include <QListWidget>

namespace Ui {
class BurnImage;
}

class BurnImage : public QWidget
{
    Q_OBJECT
signals:
    // log
    void info(QString); void warn(QString);
    void error(QString); void debug(QString);
    // logic
    void newISOPath(QString);
    void newBurner(int);
    void busness(bool);
public:
    static BurnImage *instance();
public:
    BurnImage(const BurnImage*)=delete;
    BurnImage *operator =(const BurnImage*)=delete;
public:
    void update();
    void destroy() { delete this; }
protected:
    void resizeEvent(QResizeEvent *event) Q_DECL_OVERRIDE;
private:
    explicit BurnImage(QWidget *parent = nullptr);
    ~BurnImage();
public slots:
    void slotsNewISOPath(QString);
private slots:
    void slotsBrowseISO();
    void slotsISOChange(int);
    void slotsISOError(QString);
    void slotsBurnerError(QString);
    void slotsReady(QString);
    void slotsNewBurner(QString, QString);
    void slotsDeleteBurner(int);
    void slotsBurnerChange(int);
private:
    static BurnImage *m_oInstance;
    static QMutex     m_oMutex;
private:
    QWidget          *m_oShowISO;
    QLabel           *m_oIcon;
    QLabel           *m_oDisplay;
    QWidget          *m_oShowBurner;
    QLabel           *m_oIconBurner;
    QLabel           *m_oDisplayBurner;
    QListWidget      *m_oListWidget;
    QStringList       m_oISOPaths;
    QListWidget      *m_oListWidgetBurner;
private:
    Ui::BurnImage    *ui;
};
#define PAGE_BurnImage BurnImage::instance()
#endif // BURNIMAGE_H
