/*
 * kylin-burner--Qt
 *
 * Copyright (C) 2020, Tianjin KYLIN Information Technology Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yan Huanzhang <yanhuanzhang@kylinos.cn>
 *          Wang Chenglong <wangchenglong@kylinos.cn>
 */

#include "busnesssetting.h"
#include "ui_busnesssetting.h"
#include "src/data/datacdrom.h"
#include "src/po/translation.h"
#include "src/view/modaldialog.h"
#include "src/model/logicburnimage.h"
#include "src/model/logiccopyimage.h"
#include "src/frame/signals.h"

#include <QDebug>
#include <QDir>
#include <QStorageInfo>
#include <QFileDialog>
#include <QMessageBox>

BusnessSetting::BusnessSetting(QWidget *parent) :
    QWidget(parent),
    ui(new Ui::BusnessSetting)
{
    QFont f;
    ui->setupUi(this);

    f = ui->title->font();
    f.setPixelSize(24);
    f.setWeight(100);
    ui->title->setFont(f);

    f = ui->labelISOInfo->font();
    f.setPixelSize(14);
    f.setWeight(60);
    ui->labelISOInfo->setFont(f);
    ui->labelISOInfo->setText(_("ISO info:"));
    ui->labelCopyright->setFont(f);
    ui->labelCopyright->setText(_("Copyright:"));
    ui->labelISOSetting->setFont(f);
    ui->labelISOSetting->setText(_("After ISO:"));
    ui->labelPreparer->setFont(f);
    ui->labelPreparer->setText(_("Preparer:"));
    ui->labelPublisher->setFont(f);
    ui->labelPublisher->setText(_("Publisher:"));
    ui->labelVolumnID->setFont(f);
    ui->labelVolumnID->setText(_("VoumnID:"));
    ui->labelTempPath->setFont(f);
    ui->labelTempPath->setText(_("Temporary path:"));
    ui->labelBurnerSetting->setFont(f);
    ui->labelBurnerSetting->setText(_("After burned:"));
    ui->labelBurnSpeed->setFont(f);
    ui->labelBurnSpeed->setText(_("Burn Speed:"));
    ui->labelBurnFormat->setFont(f);
    ui->labelBurnFormat->setText(_("Burn Format"));
    f = ui->btnBrowse->font();
    f.setPixelSize(14);
    ui->lineEditCopyright->setFont(f);
    ui->lineEditPreparer->setFont(f);
    ui->lineEditPublisher->setFont(f);
    ui->lineEditTempPath->setFont(f);
    ui->lineEditVolumnID->setFont(f);
    ui->comboBoxBurnSpeed->setFont(f);
    ui->comboBoxBurnFormat->setFont(f);
    ui->btnBrowse->setFont(f);
    ui->btnBrowse->setText(_("Browse"));
    ui->checkBoxBunerClean->setFont(f);
    ui->checkBoxBunerClean->setText(_("Clean File(s)"));
    ui->checkBoxClean->setFont(f);
    ui->checkBoxClean->setText(_("Clean File(s)"));
    ui->checkBoxCloseSeeion->setFont(f);
    ui->checkBoxCloseSeeion->setText(_("Close session"));
    ui->checkBoxCreateISO->setFont(f);
    ui->checkBoxCreateISO->setText(_("Create ISO"));
    ui->checkBoxOpen->setFont(f);
    ui->checkBoxOpen->setText(_("Open belong URL"));
    ui->checkBoxBunerClean->hide();


    m_oBrowsePath.clear();
    m_oCDROM = nullptr;

    connect(ui->btnBrowse, SIGNAL(clicked(bool)), this, SLOT(slotsBrowse()));
    connect(ui->lineEditCopyright, SIGNAL(textEdited(QString)), this, SLOT(slotsChange()));
    connect(ui->lineEditPreparer, SIGNAL(textEdited(QString)), this, SLOT(slotsChange()));
    connect(ui->lineEditPublisher, SIGNAL(textEdited(QString)), this, SLOT(slotsChange()));
    connect(ui->lineEditVolumnID, SIGNAL(textEdited(QString)), this, SLOT(slotsChange()));
    connect(ui->lineEditTempPath, SIGNAL(editingFinished()), this, SLOT(slotsChange()));
    connect(ui->checkBoxBunerClean, SIGNAL(stateChanged(int)), this, SLOT(slotsChange()));
    connect(ui->checkBoxClean, SIGNAL(stateChanged(int)), this, SLOT(slotsChange()));
    connect(ui->checkBoxCloseSeeion, SIGNAL(stateChanged(int)), this, SLOT(slotsChange()));
    connect(ui->checkBoxCreateISO, SIGNAL(stateChanged(int)), this, SLOT(slotsChange()));
    connect(ui->checkBoxOpen, SIGNAL(stateChanged(int)), this, SLOT(slotsChange()));
    connect(ui->comboBoxBurnSpeed, SIGNAL(currentIndexChanged(int)), this, SLOT(slotsChange()));
    connect(ui->comboBoxBurnFormat, SIGNAL(currentIndexChanged(int)), this, SLOT(slotsChange()));

}


void BusnessSetting::load(void *d)
{
    //qDebug()<<"BusnessSetting::load  start-----";
    DataCDROM *cdrom;
    m_oCDROM = d;

    cdrom = static_cast<DataCDROM *>(d);
    //if (cdrom) cdrom->use();
    cdrom->setting();
    //qDebug()<<"cdrom.m_oSetting.load()  speed(),burnFormat()";
    //qDebug()<<"cdrom->m_oSetting->m_SBurnFormat==["<<cdrom->getBurnFormat()<<"]";
    ui->checkBoxBunerClean->setEnabled(true);
    ui->checkBoxClean->setEnabled(true);
    ui->checkBoxCloseSeeion->setEnabled(true);
    ui->checkBoxCreateISO->setEnabled(true);
    ui->checkBoxOpen->setEnabled(true);
    ui->lineEditCopyright->setReadOnly(false);
    ui->lineEditPreparer->setReadOnly(false);
    ui->lineEditPublisher->setReadOnly(false);
    ui->lineEditVolumnID->setReadOnly(false);

    if (cdrom->isCDROM() && cdrom->mediumStatus() != DataMedium::MEDIUM_EMPTY)
    {
        ui->lineEditCopyright->setReadOnly(true);
        ui->lineEditPreparer->setReadOnly(true);
        ui->lineEditPublisher->setReadOnly(true);
        ui->lineEditVolumnID->setReadOnly(true);
        ui->checkBoxCreateISO->setChecked(false);
        ui->checkBoxCreateISO->setEnabled(false);
    }
    else
    {
        ui->lineEditCopyright->setReadOnly(false);
        ui->lineEditPreparer->setReadOnly(false);
        ui->lineEditPublisher->setReadOnly(false);
        ui->lineEditVolumnID->setReadOnly(false);
        ui->checkBoxCreateISO->setChecked(true);
        ui->checkBoxCreateISO->setEnabled(true);
    }

    m_oSpeed = cdrom->mediumSpeed();
    m_oSpeeds.clear();
    while (m_oSpeed.size())
    {
        m_oSpeeds << m_oSpeed.takeFirst().toInt();
    }
    ui->comboBoxBurnSpeed->clear();
    for (int i = 0; i < m_oSpeeds.size(); ++i)
    {
        ui->comboBoxBurnSpeed->addItem(QString("%1x").arg(m_oSpeeds.at(i)));
    }
    if (0 == m_oSpeeds.size())
        ui->comboBoxBurnSpeed->setEnabled(false);
    else
        ui->comboBoxBurnSpeed->setEnabled(true);

    #if 1
    //使用UDF格式或ISO9660，默认ISO9660
    m_oBurnFormat.clear();
    ui->comboBoxBurnFormat->clear();
    m_oBurnFormat<< QString("ISO9660");
    if(cdrom->isEnableUDF())
    {  
        m_oBurnFormat<< QString("UDF");
    }
    for(int i=0; i<m_oBurnFormat.size(); ++i)
    {
        ui->comboBoxBurnFormat->addItem(QString("%1").arg(m_oBurnFormat.at(i)));
    }
    if (0 == m_oBurnFormat.size())
        ui->comboBoxBurnFormat->setEnabled(false);
    else
        ui->comboBoxBurnFormat->setEnabled(true);
    #endif

    ui->lineEditPreparer->setText(m_oPreparer);
    ui->lineEditCopyright->setText(m_oCopyright);
    ui->lineEditPublisher->setText(m_oPublisher);
    ui->lineEditVolumnID->setText(m_oVolumnID);
    ui->checkBoxBunerClean->setChecked(m_bClean);
    ui->checkBoxClean->setChecked(m_bClean);
    if (BURNIMAGE == sender() || cdrom->mediumType().contains("DVD+RW"))
    {
        m_bCloseSession = true;
    }
    else
    {
        m_bCloseSession = cdrom->settingCloseSession();
    }
    ui->checkBoxCloseSeeion->setChecked(m_bCloseSession);
    if (BURNIMAGE == sender() || cdrom->mediumType().contains("DVD"))
    {
        ui->checkBoxCloseSeeion->setEnabled(false);
        ui->checkBoxCreateISO->setEnabled(false);
        ui->lineEditCopyright->setReadOnly(true);
        ui->lineEditPreparer->setReadOnly(true);
        ui->lineEditPublisher->setReadOnly(true);
        ui->lineEditVolumnID->setReadOnly(true);
    }
    else
    {
        ui->checkBoxCloseSeeion->setEnabled(true);
    }
    if (BURNIMAGE == sender() || COPY_IMGAE == sender())
    {
        ui->btnBrowse->setEnabled(false);
    }
    else
    {
        ui->btnBrowse->setEnabled(true);
    }

    ui->checkBoxCreateISO->setChecked(m_bCreateISO);
    ui->checkBoxOpen->setChecked(m_bOpen);
    setTemporaryPath(m_oTemporaryPth);

    if (cdrom->isCDROM())
    {
        ui->title->setText(_("BurnSetting"));
        title(_("BurnSetting"));
        ui->widgetISOSetting->hide();
        ui->widgetBurnSetting->show();
        ui->widgetSpeed->show();
        ui->line->show();

        if (-1 != m_oSpeeds.indexOf(m_iSpeed))
        {
            //qDebug() <<"m_iSpeed==["<<m_iSpeed<<"]";
            ui->comboBoxBurnSpeed->setCurrentIndex(m_oSpeeds.indexOf(m_iSpeed));
        }

        if (-1 != m_oBurnFormat.indexOf(m_SBurnFormat))
        {
            //qDebug() <<"m_SBurnFormat==["<<m_SBurnFormat<<"]";
            ui->comboBoxBurnFormat->setCurrentIndex(m_oBurnFormat.indexOf(m_SBurnFormat));
        }

    }
    else
    {
        ui->title->setText(_("ISOSetting"));
        title(_("ISOSetting"));
        ui->widgetISOSetting->show();
        ui->widgetBurnSetting->hide();
        ui->widgetSpeed->hide();
        ui->line->hide();
    }

    if (COPY_IMGAE == sender())
    {
        ui->lineEditCopyright->setReadOnly(true);
        ui->lineEditPreparer->setReadOnly(true);
        ui->lineEditPublisher->setReadOnly(true);
        ui->lineEditVolumnID->setReadOnly(true);
        ui->checkBoxBunerClean->setEnabled(false);
        ui->checkBoxClean->setEnabled(false);
        ui->checkBoxCloseSeeion->setEnabled(false);
        ui->checkBoxCreateISO->setEnabled(false);
        ui->checkBoxOpen->setEnabled(false);
    }
    //if (cdrom) cdrom->release();
    //qDebug()<<"BusnessSetting::load  end-----";
}

void BusnessSetting::setTemporaryPath(QString path)
{
    int u = -1;
    QDir dir(path);
    QStorageInfo storage(path);
    qreal size = storage.bytesAvailable();
    QString name;

    while (size > 1024.00)
    {
        ++u; size /= 1024.00;
    }
    name = QString("Usage: %1 Free Space: %2").arg(dir.dirName()).arg(size, 0, 'f', 1);
    switch (u)
    {
    case 0:
        name.append(_("KB"));
        break;
    case 1:
        name.append(_("MB"));
        break;
    case 2:
        name.append(_("GB"));
        break;
    case 3:
        name.append(_("TB"));
        break;
    case 4:
        name.append(_("PB"));
        break;
    default:
        name.append(_("B"));
        break;
    }
    ui->lineEditTempPath->setText(name);
    ui->lineEditTempPath->setCursorPosition(0);
    ui->lineEditTempPath->setToolTip(name);
    m_oBrowsePath = path;
}

void BusnessSetting::slotsChange()
{
    //qDebug()<<"BusnessSetting::slotsChange start --";
    do
    {
        //qDebug()<<"do-while";
        if (m_oCopyright != ui->lineEditCopyright->text()) break;
        if (m_oPreparer != ui->lineEditPreparer->text()) break;
        if (m_oVolumnID != ui->lineEditVolumnID->text()) break;
        if (m_oPublisher != ui->lineEditPublisher->text()) break;
        if (m_oBrowsePath != m_oTemporaryPth) break;
        if (m_bClean != ui->checkBoxBunerClean->isChecked()) break;
        if (m_bClean != ui->checkBoxClean->isChecked()) break;
        if (m_bCloseSession != ui->checkBoxCloseSeeion->isChecked()) break;
        if (m_bCreateISO != ui->checkBoxCreateISO->isChecked()) break;
        if (m_bOpen != ui->checkBoxOpen->isChecked()) break;
        if (m_oSpeeds.size() && ui->comboBoxBurnSpeed->currentIndex() >= 0)
            if (m_iSpeed != m_oSpeeds.at(ui->comboBoxBurnSpeed->currentIndex())) break;
        if (m_oBurnFormat.size() && ui->comboBoxBurnFormat->currentIndex() >= 0)
        {
            if (m_SBurnFormat != m_oBurnFormat.at(ui->comboBoxBurnFormat->currentIndex())) break;
        }
        changed(false);
        return;
    } while(0);
    /*
    qDebug()<<"m_oBurnFormat.size()==["<<m_oBurnFormat.size()<<"]";
    qDebug()<<"m_SBurnFormat == ["<<m_SBurnFormat<<"]";
    qDebug()<<"ui->comboBoxBurnFormat->currentIndex() == [" << ui->comboBoxBurnFormat->currentIndex()<<"]";
    qDebug()<<"";
    qDebug()<<"m_oSpeeds.size()==["<<m_oSpeeds.size()<<"]";
    qDebug()<<"m_iSpeed == ["<<m_iSpeed<<"]";
    qDebug()<<"ui->comboBoxBurnSpeed->currentIndex() == [" << ui->comboBoxBurnSpeed->currentIndex()<<"]";
    qDebug()<<"";
    qDebug()<<"do-changed(true)";
    qDebug()<<"BusnessSetting::slotsChange end --";
    */
    changed(true);
}

void BusnessSetting::slotsBrowse()
{
    QString testPath;
    //ui->btnBrowse->setIcon(QIcon::fromTheme("folder-open"));
    m_oBrowsePath = QFileDialog::getExistingDirectory(this, _("Browse"), m_oBrowsePath);
    if (!m_oBrowsePath.isEmpty())
    {
        testPath = m_oBrowsePath + "/.t/.k";
        QDir dir(testPath);
        if (dir.mkpath(testPath))
        {
            dir.removeRecursively();
            setTemporaryPath(m_oBrowsePath);
        }
        else
        {
            QMessageBox::critical(this, _("Invalid path"),
                                  _("Cannot choose a read "
                                    "only path %1 to "
                                    "temporary path").arg(m_oBrowsePath));
            m_oBrowsePath = m_oTemporaryPth;
        }
    }
}

void BusnessSetting::slotsAccept()
{
    //qDebug()<<"BusnessSetting::slotsAccept()  start----------";
    DataCDROM *cdrom = static_cast<DataCDROM *>(m_oCDROM);
    if (!cdrom) return;
    //cdrom->use();
    cdrom->preparer(ui->lineEditPreparer->text());
    cdrom->publisher(ui->lineEditPublisher->text());
    cdrom->volumnID(ui->lineEditVolumnID->text());
    cdrom->copyright(ui->lineEditCopyright->text());
    cdrom->tempPath(m_oBrowsePath);
    if (cdrom->isCDROM())
    {

        cdrom->speed(m_oSpeeds.at(ui->comboBoxBurnSpeed->currentIndex()));
        cdrom->burnFormat(m_oBurnFormat.at(ui->comboBoxBurnFormat->currentIndex()));
        cdrom->clean(ui->checkBoxBunerClean->isChecked());
        cdrom->closeSession(ui->checkBoxCloseSeeion->isChecked());
        cdrom->createISO(ui->checkBoxCreateISO->isChecked());
        emit g_user_signal->changeBtnBusnessName();
        //qDebug()<<"BusnessSetting::slotsAccept  speed("<<m_oSpeeds.at(ui->comboBoxBurnSpeed->currentIndex())<<")";
        //qDebug()<<"BusnessSetting::slotsAccept  burnFormat("<<m_oBurnFormat.at(ui->comboBoxBurnFormat->currentIndex())<<")";


    }
    else
    {
        cdrom->clean(ui->checkBoxClean->isChecked());
        cdrom->setOpen(ui->checkBoxOpen->isChecked());
    }

    //cdrom->release();
    disconnect(MODAL, SIGNAL(accepted()), this, SLOT(slotsAccept()));

    //qDebug()<<"BusnessSetting::slotsAccept()  end-------------";
}

BusnessSetting::~BusnessSetting()
{
    delete ui;
}
