/*
 * kylin-burner--Qt
 *
 * Copyright (C) 2020, Tianjin KYLIN Information Technology Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yan Huanzhang <yanhuanzhang@kylinos.cn>
 *          Wang Chenglong <wangchenglong@kylinos.cn>
 */

#include "execdialog.h"
#include "ui_execdialog.h"
#include "src/frame/xatom-helper.h"
#include "src/frame/configuration.h"
#include "src/po/translation.h"
#include "src/model/logicmain.h"

#include <QPushButton>

ExecDialog *ExecDialog::m_oInstance = nullptr;
QMutex      ExecDialog::m_oMutex;

ExecDialog::ExecDialog(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::ExecDialog)
{
    QFont f;
    ui->setupUi(this);
    MotifWmHints hints;
    hints.flags = MWM_HINTS_FUNCTIONS | MWM_HINTS_DECORATIONS;
    hints.functions = MWM_FUNC_ALL;
    hints.decorations = MWM_DECOR_BORDER;
    XAtomHelper::getInstance()->setWindowMotifHint(winId(), hints);

    ui->title->onlyShowInDialog();
    connect(ui->title, SIGNAL(close()), this, SLOT(close()));
    connect(this, SIGNAL(windowIconChanged(QIcon)), ui->title, SLOT(onWindowIconChange(QIcon)));
    connect(this, SIGNAL(windowTitleChanged(QString)), ui->title, SLOT(onWindowTitleChange(QString)));
    connect(this, SIGNAL(content(QString)), ui->inputPage, SIGNAL(content(QString)));
    connect(this, SIGNAL(result(QString)), ui->inputPage, SIGNAL(result(QString)));
    connect(ui->tip, SIGNAL(checked(bool)), this, SLOT(slotsTipsAgain(bool)));
    setWindowIcon(QIcon::fromTheme("burner"));
    setWindowTitle(_("Burner"));
    f = ui->buttonBox->font();
    f.setPixelSize(14);
    ui->buttonBox->setFont(f);
}

ExecDialog *ExecDialog::instance()
{
    if (nullptr == m_oInstance)
    {
        QMutexLocker locker(&m_oMutex);
        if (nullptr == m_oInstance)
        {
            m_oInstance = new ExecDialog();
        }
    }
    return m_oInstance;
}

int ExecDialog::information(QString title, QString content, bool next)
{
    setWindowTitle(_("Burner") + " - " + title);
    ui->stackedWidget->setCurrentIndex(1);
    ui->tip->information(content, next);
    ui->buttonBox->setStandardButtons(QDialogButtonBox::Ok);
    ui->buttonBox->button(QDialogButtonBox::Ok)->setText(_("OK"));
    return ExecDialog::exec();
}

void ExecDialog::error(QString title, QString content, bool next)
{
    m_oTipTitle = title;
    if (CFG->get("EXEC", title, false).toBool()) return;
    setWindowTitle(_("Burner") + " - " + title);
    ui->stackedWidget->setCurrentIndex(1);
    ui->buttonBox->setStandardButtons(QDialogButtonBox::Ok);
    ui->buttonBox->button(QDialogButtonBox::Ok)->setText(_("OK"));
    ui->tip->error(content, next);
    ExecDialog::exec();
}

bool ExecDialog::question(QString title, QString content, bool next)
{
    m_oTipTitle = title;
    if (CFG->get("EXEC", title, false).toBool()) return true;
    setWindowTitle(_("Burner") + " - " + title);
    ui->stackedWidget->setCurrentIndex(1);
    ui->buttonBox->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
    ui->buttonBox->button(QDialogButtonBox::Ok)->setText(_("OK"));
    ui->buttonBox->button(QDialogButtonBox::Cancel)->setText(_("Cancel"));
    ui->tip->question(content, next);
    return ExecDialog::exec();
}

QString ExecDialog::input(QString title, QString content, QString result)
{
    setWindowTitle(_("Burner") + " - " + title);
    this->content(content);
    this->result(result);
    ui->stackedWidget->setCurrentIndex(0);
    ui->buttonBox->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
    ui->buttonBox->button(QDialogButtonBox::Ok)->setText(_("OK"));
    ui->buttonBox->button(QDialogButtonBox::Cancel)->setText(_("Cancel"));
    if (ExecDialog::exec())
    {
        return ui->inputPage->result();
    }
    return QString();
}

bool ExecDialog::input(QString &inputed, QString title , QString content, QString result)
{
    setWindowTitle(_("Burner") + " - " + title);
    this->content(content);
    this->result(result);
    ui->stackedWidget->setCurrentIndex(0);
    ui->buttonBox->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
    ui->buttonBox->button(QDialogButtonBox::Ok)->setText(_("OK"));
    ui->buttonBox->button(QDialogButtonBox::Cancel)->setText(_("Cancel"));
    inputed.clear();
    if (ExecDialog::exec())
    {
        inputed = ui->inputPage->result();
        return true;
    }
    return false;
}

void ExecDialog::paintEvent(QPaintEvent *event)
{
    QPalette pal = palette();
    if ("ukui-black" == MAIN->theme())
        pal.setBrush(QPalette::Background, QColor("#484848"));
    else
        pal.setBrush(QPalette::Background, QColor("#FFFFFF"));
    setPalette(pal);
    QDialog::paintEvent(event);
}

void ExecDialog::slotsTipsAgain(bool b)
{
    CFG->set("EXEC", m_oTipTitle, b);
}

ExecDialog::~ExecDialog()
{
    delete ui;
}
