/*
 * kylin-burner--Qt
 *
 * Copyright (C) 2020, Tianjin KYLIN Information Technology Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yan Huanzhang <yanhuanzhang@kylinos.cn>
 *          Wang Chenglong <wangchenglong@kylinos.cn>
 */

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QButtonGroup>

QT_BEGIN_NAMESPACE
namespace Ui { class MainWindow; }
QT_END_NAMESPACE

class MainWindow : public QMainWindow
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.ukui.kylinburner.play")
signals:
    // log
    void info(QString); void warn(QString);
    void error(QString); void debug(QString);
    // busness
    void busness(int);
    // move
    void position(QPoint);
    // browse
    void browse(QString);
    // delete datas
    void delData(int);
public:
    MainWindow(QStringList args, QWidget *parent = nullptr);
    ~MainWindow();
protected:
    void closeEvent(QCloseEvent *event) Q_DECL_OVERRIDE;
    void moveEvent(QMoveEvent *event) Q_DECL_OVERRIDE;
    void paintEvent(QPaintEvent *event) Q_DECL_OVERRIDE;
public slots:
    void slotsReShowMainWindow();
private slots:
    void slotsBurnData();
    void slotsBurnImage();
    void slotsCopyImage();
    void slotsAdjustBurnData(int idx);
    void slotsBusness(bool);
    void slotsInitCreateISO(void *);
    void slotsNoMediun(void *);
    void slotsRemoveCDROM(void *);
    void slotsBrowseOrSetting(bool);
    void slotsUpdateDisk(int, void *);
    void slotsCloseAll();
    void slotsChangeName(int);
    void slotsChangeBtnBusnessName();
    void slotsShowTip_loadMedium();
    void slotsHideTip_loadMedium();
private:
    bool started();
private:
    QButtonGroup   *m_oGroup;
    QList<void *>   m_oCDROMS;
private:
    Ui::MainWindow *ui;
};
#endif // MAINWINDOW_H
