/*
 * kylin-burner--Qt
 *
 * Copyright (C) 2020, Tianjin KYLIN Information Technology Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yan Huanzhang <yanhuanzhang@kylinos.cn>
 *          Wang Chenglong <wangchenglong@kylinos.cn>
 */

#ifndef MODALDIALOG_H
#define MODALDIALOG_H

#include <QDialog>
#include <QMutex>
#include <QPoint>

namespace Ui {
class ModalDialog;
}

class ModalDialog : public QDialog
{
    Q_OBJECT
public:
    enum Pages
    {
        Progress = 0,
        Tip,
        BusnessSetting,
        DataSetting,
        DiskCheck
    };

public:
    static ModalDialog *instance();
public:
    ModalDialog(const ModalDialog*)=delete;
    ModalDialog *operator =(const ModalDialog*)=delete;
public:
    void init(){}
    void destroy() { delete this; }
public slots:
    QWidget *showPage(int);
    void cancelEnable(bool);
    void updatePosition(QPoint);
    void show();
    bool canBeClose() { return m_bCanClose; }
protected:
    void paintEvent(QPaintEvent *event) Q_DECL_OVERRIDE;
    void closeEvent(QCloseEvent *event) Q_DECL_OVERRIDE;
private:
    explicit ModalDialog(QWidget *parent = nullptr);
    ~ModalDialog();
private slots:
    void slotsTitle(QString);
    void slotsClose();
private:
    static ModalDialog *m_oInstance;
    static QMutex       m_oMutex;
private:
    bool                m_bCanClose;
    QPoint              m_oMainPos;
private:
    Ui::ModalDialog    *ui;
signals:
    // log
    void info(QString); void warn(QString);
    void error(QString); void debug(QString);
    void cancel();
};

#define MODAL ModalDialog::instance()
#define PROGRESS MODAL->showPage(ModalDialog::Progress)
#define TIP MODAL->showPage(ModalDialog::Tip)
#define BUSNESSSETTING MODAL->showPage(ModalDialog::BusnessSetting)
#define DATASETTING MODAL->showPage(ModalDialog::DataSetting)
#define DISKCHECK MODAL->showPage(ModalDialog::DiskCheck)

#endif // MODALDIALOG_H
