/*
 * kylin-burner--Qt
 *
 * Copyright (C) 2020, Tianjin KYLIN Information Technology Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yan Huanzhang <yanhuanzhang@kylinos.cn>
 *          Wang Chenglong <wangchenglong@kylinos.cn>
 */

#include "progress.h"
#include "ui_progress.h"
#include "src/view/modaldialog.h"

#define ICON_SIZE QSize(16, 16)

Progress::Progress(QWidget *parent) :
    QWidget(parent),
    ui(new Ui::Progress)
{
    QFont f;
    ui->setupUi(this);
    f = ui->labelTitle->font();
    ui->labelTitle->setFocusPolicy(Qt::NoFocus);
    f.setPixelSize(24);
    f.setWeight(100);
    ui->labelTitle->setFont(f);
    ui->labelIcon->setProperty("useIconHighlightEffect", 0x8);

    f = ui->labelContent->font();
    f.setPixelSize(14);
    ui->labelContent->setFont(f);
    ui->progressBar->setFont(f);
    ui->progressBar->setValue(0);

    connect(this, SIGNAL(title(QString)), ui->labelTitle, SLOT(setText(QString)));
    connect(this, SIGNAL(setRange(int,int)), ui->progressBar, SLOT(setRange(int,int)));
    connect(this, SIGNAL(setValue(int,QIcon,QString)), this, SLOT(slotsSetValue(int,QIcon,QString)));
    connect(this, SIGNAL(addValue(int,QIcon,QString)), this, SLOT(slotsAddValue(int,QIcon,QString)));
}

void Progress::slotsSetValue(int value, QIcon icon, QString str)
{
    QCoreApplication::processEvents();
    ui->progressBar->setValue(value);
    ui->labelIcon->setPixmap(icon.pixmap(ICON_SIZE));
    ui->labelContent->setText(str);
    //ui->labelContent->setToolTip(str);
    if (ui->progressBar->value() == ui->progressBar->maximum())
    {
        MODAL->accept();
    }
}

void Progress::slotsAddValue(int value, QIcon icon, QString str)
{
    QCoreApplication::processEvents();
    value += ui->progressBar->value();
    ui->progressBar->setValue(value);
    ui->labelIcon->setPixmap(icon.pixmap(ICON_SIZE));
    ui->labelContent->setText(str);
    //ui->labelContent->setToolTip(str);
    if (ui->progressBar->value() == ui->progressBar->maximum())
    {
        MODAL->accept();
    }
}

void Progress::slotsUpdateIcon(QIcon icon)
{
    ui->labelIcon->setPixmap(icon.pixmap(ICON_SIZE));
}

Progress::~Progress()
{
    delete ui;
}
