/*
 * kylin-burner--Qt
 *
 * Copyright (C) 2020, Tianjin KYLIN Information Technology Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yan Huanzhang <yanhuanzhang@kylinos.cn>
 *          Wang Chenglong <wangchenglong@kylinos.cn>
 */

#include "tip_loadmedium.h"
#include "ui_tip_loadmedium.h"
#include "src/frame/xatom-helper.h"
#include "src/po/translation.h"
#include "src/model/logicmain.h"

#include <QMoveEvent>
#define ICON_SIZE QSize(24, 24)

Tip_loadMedium *Tip_loadMedium::m_oInstance = nullptr;
QMutex       Tip_loadMedium::m_oMutex;

Tip_loadMedium::Tip_loadMedium(QWidget *parent) :
    QDialog(parent),
    m_u32Icon(0),
    m_oIcon(QIcon::fromTheme("ukui-loading-0")),
    m_oTimer(new QTimer(this)),
    ui(new Ui::Tip_loadMedium)
{
    QFont f;
    ui->setupUi(this);


    MotifWmHints hints;
    hints.flags = MWM_HINTS_FUNCTIONS | MWM_HINTS_DECORATIONS;
    hints.functions = MWM_FUNC_ALL;
    hints.decorations = MWM_DECOR_BORDER;
    XAtomHelper::getInstance()->setWindowMotifHint(winId(), hints);

    setAttribute(Qt::WA_ShowModal, true);

    ui->label->setText(_("medium load/pop-up"));

    setFixedSize(201, 56);

    f = ui->label->font();
    f.setPixelSize(12);
    ui->label->setFont(f);

}

Tip_loadMedium::~Tip_loadMedium()
{
    delete m_oTimer;
    delete ui;
}

void Tip_loadMedium::init()
{

    connect(m_oTimer, SIGNAL(timeout()), this, SLOT(slotsSetIcon()));
}

Tip_loadMedium *Tip_loadMedium::instance()
{
    if (nullptr == m_oInstance)
    {
        QMutexLocker locker(&m_oMutex);
        if (nullptr == m_oInstance)
        {
            m_oInstance = new Tip_loadMedium();
        }
    }
    return m_oInstance;
}

void Tip_loadMedium::show()
{
    m_oTimer->start(100);
    m_u32Icon = 0;
    m_oIcon = QIcon::fromTheme(QString("ukui-loading-%1").arg((m_u32Icon++) % 8));
    ui->labelIcon->setPixmap(m_oIcon.pixmap(ICON_SIZE));

    move(m_oPosition);
    QWidget::show();
    //setVisible(true);

}
void Tip_loadMedium::hide()
{
    m_oTimer->stop();
    move(m_oPosition);
    QWidget::hide();
    //setVisible(false);
}
void Tip_loadMedium::slotsSetIcon()
{
    m_oIcon = QIcon::fromTheme(QString("ukui-loading-%1").arg((m_u32Icon++) % 8));
    //qDebug()<<"m_u32Icon="<<m_u32Icon;
    ui->labelIcon->setPixmap(m_oIcon.pixmap(ICON_SIZE));
}



void Tip_loadMedium::updatePosition(QPoint p)
{
    m_oPosition.setX(p.x() - width() / 2);
    m_oPosition.setY(p.y() - height() / 2);
}

void Tip_loadMedium::paintEvent(QPaintEvent *event)
{
    QPalette pal = palette();
    if ("ukui-black" == MAIN->theme())
        pal.setBrush(QPalette::Background, QColor("#484848"));
    else
        pal.setBrush(QPalette::Background, QColor("#FFFFFF"));
    setPalette(pal);
    QDialog::paintEvent(event);
}

