/*
 * kylin-burner--Qt
 *
 * Copyright (C) 2020, Tianjin KYLIN Information Technology Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yan Huanzhang <yanhuanzhang@kylinos.cn>
 *          Wang Chenglong <wangchenglong@kylinos.cn>
 */

#include "tips.h"
#include "ui_tips.h"
#include "src/po/translation.h"
#include "src/view/modaldialog.h"

#define ICON_SIZE QSize(30, 30)

tips::tips(QWidget *parent) :
    QWidget(parent),
    ui(new Ui::tips)
{
    ui->setupUi(this);
    connect(this, SIGNAL(success(QString)), this, SLOT(slotsSuccess(QString)));
    connect(this, SIGNAL(fail(QString)), this, SLOT(slotsFailed(QString)));
    connect(ui->checkBox, SIGNAL(toggled(bool)), this, SIGNAL(checked(bool)));
}

void tips::information(QString content, bool next)
{
    QFont f;

    f = ui->labelContent->font();
    f.setPixelSize(16);
    ui->labelContent->setFont(f);
    f=ui->checkBox->font();
    f.setPixelSize(16);
    ui->labelContent->setText(content);
    ui->checkBox->setText(_("Donot show agian."));
    ui->checkBox->setChecked(false);
    ui->checkBox->setHidden(next);
    ui->labelLogo->setPixmap(QIcon::fromTheme("dialog-information-symbolic").pixmap(ICON_SIZE));
}

void tips::error(QString content, bool next)
{
    QFont f;

    f = ui->labelContent->font();
    f.setPixelSize(16);
    ui->labelContent->setFont(f);
    f=ui->checkBox->font();
    f.setPixelSize(16);
    ui->labelContent->setText(content);
    ui->checkBox->setText(_("Donot show agian."));
    ui->checkBox->setChecked(false);
    ui->checkBox->setHidden(next);
    ui->labelLogo->setPixmap(QIcon::fromTheme("dialog-error-symbolic").pixmap(ICON_SIZE));
}

void tips::question(QString content, bool next)
{
    QFont f;

    f = ui->labelContent->font();
    f.setPixelSize(16);
    ui->labelContent->setFont(f);
    f=ui->checkBox->font();
    f.setPixelSize(16);
    ui->checkBox->setFont(f);
    ui->labelContent->setText(content);
    ui->checkBox->setChecked(false);
    ui->checkBox->setText(_("Donot show agian."));
    ui->checkBox->setHidden(next);
    ui->labelLogo->setPixmap(QIcon::fromTheme("dialog-question-symbolic").pixmap(ICON_SIZE));
}

void tips::slotsSuccess(QString name)
{
    QFont f;

    MODAL->showPage(ModalDialog::Tip);
    MODAL->show();

    f = ui->labelContent->font();
    f.setPixelSize(24);
    f.setWeight(400);
    ui->widgetCheckBox->hide();
    ui->labelContent->setFont(f);
    ui->labelContent->setAlignment(Qt::AlignVCenter | Qt::AlignLeft);
    ui->labelContent->setText(name + _(" Success"));
    ui->labelLogo->setPixmap(QIcon::fromTheme("ukui-dialog-success").pixmap(ICON_SIZE));
}

void tips::slotsFailed(QString name)
{
    QFont f;

    MODAL->showPage(ModalDialog::Tip);
    MODAL->show();

    f = ui->labelContent->font();
    f.setPixelSize(24);
    f.setWeight(400);
    ui->widgetCheckBox->hide();
    ui->labelContent->setFont(f);
    ui->labelContent->setAlignment(Qt::AlignVCenter | Qt::AlignLeft);
    ui->labelContent->setText(name + _(" Failed"));
    ui->labelLogo->setPixmap(QIcon::fromTheme("dialog-error").pixmap(ICON_SIZE));
}

tips::~tips()
{
    delete ui;
}
